Plugin Configuration
====================

Web UI for runtime plugin management, mounted as sys_app at ``/_sys/plugin_config/``.

Application
-----------

.. automodule:: genro_asgi.sys_applications.plugin_config.plugin_config_app
   :members:
   :undoc-members:
   :show-inheritance:
